@@ -2,10 +2,12 @@
 
 if [ ! -e /etc/passwd -a ! -L /etc/passwd ] ; then
   /bin/mkpasswd -l -c > /etc/passwd
+  /bin/chmod 777 /etc/passwd
 fi
 
 if [ ! -e /etc/group -a ! -L /etc/group ] ; then
   /bin/mkgroup -l -c > /etc/group
+  /bin/chmod 777 /etc/group
 fi
 
 cp -f /etc/passwd /tmp/passwd.mkpasswd && \
